"""mmMBop

Usage:
  cli.py
  cli.py <mbfile>...
  cli.py (-h | --help)
  cli.py --version

Options:
  -h --help     Show this screen.
  --version     Show version.

"""

from MBTile import MBTile
from MBTilesMetadata import MBTilesMetadata
from flask import Flask, render_template, Response
from flask_cors import CORS
from docopt import docopt
import json
import util
import config
app = Flask(__name__)
CORS(app)


@app.route("/")
def main():
    mb_tiles_metadata = MBTilesMetadata(app.config['sources'])
    md = mb_tiles_metadata.get_metadata()

    return render_template('map.html', metadata=json.dumps(md))


@app.route("/get_tiles/<int:src_index>/<int:z>/<int:x>/<int:y>")
def get_tiles(src_index, z, x, y):
    source = app.config['sources'][src_index]
    tile = MBTile(source, z, x, y)
    data = tile.get_data()

    resp = Response(data)
    resp.headers['Content-type'] = 'application/x-protobuf'
    resp.headers['Content-Encoding'] = 'gzip'

    return resp


def serve():
    options = docopt(__doc__, version='{} {}'.format(config.name, config.version))
    util.parse_args(options, app)

    app.run(debug=True)

if __name__ == "__main__":
    serve()



import sqlite3


class MBTile:

    def __init__(self, src, z, x, y):
        self.conn = sqlite3.connect(src)
        self.z = z
        self.x = x
        self.y = y

    def get_data(self):
        # TODO ask a competent person what this does
        self.y = (1 << self.z) - 1 - self.y

        c = self.conn.cursor()
        c.execute(
            '''select tile_data from tiles where zoom_level=%s and tile_column=%s and tile_row=%s''' % (
                self.z, self.x, self.y
            )
        )

        result = c.fetchone()
        return bytes(result[0]) if result else []



name = 'mmmbop'
packages = ['mmmbop']
version = '0.1.8'
description = 'View MBtiles on localhost'
author = 'Laurier Rochon'
author_email = 'l@pwd.io'
url = 'https://github.com/l-r/mmmbop'
download_url = 'https://github.com/l-r/mmmbop/tarball/{}'.format(version)
keywords = ['MBtiles']
classifiers = []
include_package_data = True



import sqlite3
import json


class MBTilesMetadata:
    def __init__(self, sources):
        self.sources = sources

    @staticmethod
    def _parse_json(data):
        values = {}
        for item in data:
            name, value = item
            if name == "name":
                values['name'] = value
            if name == "json":
                data = json.loads(value)
                values['layer_id'] = [v for f in data['vector_layers'] for k, v in f.items() if k == "id"]  # yolo
                if values['layer_id']:
                    values['layer_id'] = values['layer_id'][0]
        return values

    def get_metadata(self):
        # TODO write py-node-mbtiles one day to avoid this quagmire
        all_metadata = []
        for index, _ in enumerate(self.sources):
            conn = sqlite3.connect(self.sources[index])
            c = conn.cursor()
            c.execute('''select * from metadata''')
            result = c.fetchall()

            values = self._parse_json(result)
            all_metadata.append(values)

        return all_metadata



import glob
import sys
import logging


def parse_args(arguments, app):
    sources = arguments.get('<mbfile>')
    if not sources:
        files = glob.glob("*.mbtiles")
        if not files:
            logging.error('Could not find any .mbtiles in this directory. Please specify an .mbtiles file.')
            sys.exit(1)

        app.config['sources'] = files
    else:
        app.config['sources'] = sources



from setuptools import setup
from mmmbop.config import *

setup(
    name=name,
    packages=packages,
    include_package_data=include_package_data,
    version=version,
    description=description,
    author=author,
    author_email=author_email,
    url=url,
    download_url=download_url,
    keywords=keywords,
    classifiers=[],
    install_requires=[
        "docopt==0.6.2",
        "Flask==0.10.1",
        "Flask-Cors==2.1.2",
        "itsdangerous==0.24",
        "Jinja2==2.8",
        "MarkupSafe==0.23",
        "six==1.10.0",
        "Werkzeug==0.11.10"
    ],
    entry_points={
        'console_scripts': ['mmmbop=mmmbop.cli:serve'],
    }
)
